@@ -8,10 +8,10 @@ pyside_library_soversion = "6.10"
 version = "6.10.2"
 version_info = (6, 10, 2, "", "")
 
-__build_date__ = '2026-02-02T15:44:31+00:00'
-__build_commit_date__ = '2026-02-02T15:05:38+00:00'
-__build_commit_hash__ = '2eae7b7f3c7b299f107ae9393d1fffb567805e62'
-__build_commit_hash_described__ = '6.10.2-1'
+__build_date__ = '2026-02-07T19:09:48+00:00'
+
+
+
 
 
 
